0.9.9 API documentation: raw_data.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
raw_data.hpp File Reference

GLM_GTX_raw_data More...

Go to the source code of this file.

## Typedefs
typedef detail::uint8 | byte
| Type for byte numbers. More...
typedef detail::uint32 | dword
| Type for dword numbers. More...
typedef detail::uint64 | qword
| Type for qword numbers. More...
typedef detail::uint16 | word
| Type for word numbers. More...

## Detailed Description

GLM_GTX_raw_data

See also
  Core features (dependence)

Definition in file raw_data.hpp.